import { HitTestArguments, type HitTestResult, type KeyDownEventType, type MouseDownEventType, type MouseEnterEventType, type MouseLeaveEventType, type MouseMoveEventType, type MouseUpEventType, type OxyColor, type OxyKeyEventArgs, type OxyMouseDownEventArgs, type OxyMouseEventArgs, type OxyTouchEventArgs, PlotElement, type TouchCompletedEventType, type TouchDeltaEventType, type TouchStartedEventType } from '..';
export interface CreateModelOptions {
    selectionColor?: OxyColor;
}
export declare const DefaultCreateModelOptions: CreateModelOptions;
/**
 * An abstract base class for graphics models.
 */
export declare abstract class Model {
    /**
     * The default selection color.
     */
    static readonly DefaultSelectionColor: "#ff0";
    /**
     * Initializes a new instance of the `Model` class.
     */
    protected constructor(opt?: CreateModelOptions);
    /**
     * Gets or sets the color of the selection.
     */
    selectionColor: OxyColor;
    /**
     * Returns the elements that are hit at the specified position.
     * @param args The hit test arguments.
     * @returns
     * A sequence of hit results.
     */
    hitTest(args: HitTestArguments): HitTestResult[];
    /**
     * Gets all elements of the model, top-level elements first.
     * @returns An enumerator of the elements.
     */
    protected abstract getHitTestElements(): PlotElement[];
    private static readonly mouseHitTolerance;
    private currentMouseEventElement?;
    private currentTouchEventElement?;
    /**
     * Raised when a key is pressed down. (Obsolete)
     * @deprecated Will be removed in v4.0 (#111)
     */
    keyDown?: KeyDownEventType;
    /**
     * Raised when a mouse button is pressed down. (Obsolete)
     * @deprecated Will be removed in v4.0 (#111)
     */
    mouseDown?: MouseDownEventType;
    /**
     * Raised when the mouse is moved. (Obsolete)
     * @deprecated Will be removed in v4.0 (#111)
     */
    mouseMove?: MouseMoveEventType;
    /**
     * Raised when the mouse button is released. (Obsolete)
     * @deprecated Will be removed in v4.0 (#111)
     */
    mouseUp?: MouseUpEventType;
    /**
     * Raised when the mouse cursor enters the plot area. (Obsolete)
     * @deprecated Will be removed in v4.0 (#111)
     */
    mouseEnter?: MouseEnterEventType;
    /**
     * Raised when the mouse cursor leaves the plot area. (Obsolete)
     * @deprecated Will be removed in v4.0 (#111)
     */
    mouseLeave?: MouseLeaveEventType;
    /**
     * Raised when a touch gesture starts. (Obsolete)
     * @deprecated Will be removed in v4.0 (#111)
     */
    touchStarted?: TouchStartedEventType;
    /**
     * Raised when a touch gesture changes. (Obsolete)
     * @deprecated Will be removed in v4.0 (#111)
     */
    touchDelta?: TouchDeltaEventType;
    /**
     * Raised when a touch gesture completes. (Obsolete)
     * @deprecated Will be removed in v4.0 (#111)
     */
    touchCompleted?: TouchCompletedEventType;
    /**
     * Handles mouse down events.
     * @deprecated Will be removed in v4.0 (#111)
     */
    handleMouseDown(sender: object, e: OxyMouseDownEventArgs): void;
    /**
     * Handles mouse move events.
     * @deprecated Will be removed in v4.0 (#111)
     */
    handleMouseMove(sender: object, e: OxyMouseEventArgs): void;
    /**
     * Handles mouse up events.
     * @deprecated Will be removed in v4.0 (#111)
     * @param sender
     * @param e
     */
    handleMouseUp(sender: object, e: OxyMouseEventArgs): void;
    /**
     * Handles mouse enter events.
     * @deprecated Will be removed in v4.0 (#111)
     */
    handleMouseEnter(sender: object, e: OxyMouseEventArgs): void;
    /**
     * Handles mouse leave events.
     * @deprecated Will be removed in v4.0 (#111)
     */
    handleMouseLeave(sender: object, e: OxyMouseEventArgs): void;
    /**
     * Handles the touch started event.
     * @param sender The sender.
     * @param e A `OxyTouchEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    handleTouchStarted(sender: object, e: OxyTouchEventArgs): void;
    /**
     * Handles the touch delta event.
     * @param sender The sender.
     * @param e A `OxyTouchEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    handleTouchDelta(sender: object, e: OxyTouchEventArgs): void;
    /**
     * Handles the touch completed event.
     * @param sender The sender.
     * @param e A `OxyTouchEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    handleTouchCompleted(sender: object, e: OxyTouchEventArgs): void;
    /**
     * Handles key down events.
     * @param sender The sender.
     * @param e The `OxyKeyEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    handleKeyDown(sender: object, e: OxyKeyEventArgs): void;
    /**
     * Raises the `KeyDown` event.
     * @param sender The sender.
     * @param e The `OxyMouseEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    protected onKeyDown(sender: object, e: OxyKeyEventArgs): void;
    /**
     * Raises the `MouseDown` event.
     * @param sender The sender.
     * @param e The `OxyMouseEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    protected onMouseDown(sender: object, e: OxyMouseDownEventArgs): void;
    /**
     * Raises the `MouseMove` event.
     * @param sender The sender.
     * @param e The `OxyMouseEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    protected onMouseMove(sender: object, e: OxyMouseEventArgs): void;
    /**
     * Raises the `MouseUp` event.
     * @param sender The sender.
     * @param e The `
     * @deprecated Will be removed in v4.0 (#111)
     */
    protected onMouseUp(sender: object, e: OxyMouseEventArgs): void;
    /**
     * Raises the `MouseEnter` event.
     * @param sender The sender.
     * @param e The `OxyMouseEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    protected onMouseEnter(sender: object, e: OxyMouseEventArgs): void;
    /**
     * Raises the `MouseLeave` event.
     * @param sender The sender.
     * @param e The `OxyMouseEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    protected onMouseLeave(sender: object, e: OxyMouseEventArgs): void;
    /**
     * Raises the `MouseDown` event.
     * @param sender The sender.
     * @param e The `OxyMouseEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    protected onTouchStarted(sender: object, e: OxyTouchEventArgs): void;
    /**
     * Raises the `MouseMove` event.
     * @param sender The sender.
     * @param e The `OxyMouseEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    protected onTouchDelta(sender: object, e: OxyTouchEventArgs): void;
    /**
     * Raises the `MouseUp` event.
     * @param sender The sender.
     * @param e The `OxyMouseEventArgs` instance containing the event data.
     * @deprecated Will be removed in v4.0 (#111)
     */
    protected onTouchCompleted(sender: object, e: OxyTouchEventArgs): void;
}
//# sourceMappingURL=Model.d.ts.map