import { Axis, type BarItemBase, BarSeriesManager, CategoryAxis, type CreateXYAxisSeriesOptions, type IBarSeries, type IRenderContext, LabelPlacement, type LabelStringFormatterType, type OxyColor, XYAxisSeries } from '../..';
export interface CreateBarSeriesBaseOptions extends CreateXYAxisSeriesOptions {
    barWidth?: number;
    strokeColor?: OxyColor;
    strokeThickness?: number;
    labelColor?: OxyColor;
    labelMargin?: number;
    labelAngle?: number;
    labelPlacement?: LabelPlacement;
    labelStringFormatter?: LabelStringFormatterType;
    items?: BarItemBase[];
}
export declare const DefaultBarSeriesBaseOptions: CreateBarSeriesBaseOptions;
export declare const ExtendedDefaultBarSeriesBaseOptions: {
    barWidth?: number | undefined;
    strokeColor?: string | undefined;
    strokeThickness?: number | undefined;
    labelColor?: string | undefined;
    labelMargin?: number | undefined;
    labelAngle?: number | undefined;
    labelPlacement?: LabelPlacement | undefined;
    labelStringFormatter?: LabelStringFormatterType | undefined;
    items?: BarItemBase[] | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('../..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('../..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('../..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: CreateXYAxisSeriesOptions;
};
/**
 * Base class for bar series.
 */
export declare abstract class BarSeriesBase<T extends BarItemBase> extends XYAxisSeries implements IBarSeries {
    /**
     * The default category axis title
     */
    protected static readonly DefaultCategoryAxisTitle = "Category";
    /**
     * The default value axis title
     */
    protected static readonly DefaultValueAxisTitle = "Value";
    /**
     * The width of the bars. The default value is 1.
     */
    barWidth: number;
    /**
     * The items from the items source.
     */
    protected itemsSourceItems?: T[];
    /**
     * The color of the border around the bars.
     */
    strokeColor: OxyColor;
    /**
     * The thickness of the bar border strokes.
     */
    strokeThickness: number;
    private _manager?;
    /**
     * The manager of this BarSeriesBase.
     */
    get manager(): BarSeriesManager | undefined;
    set manager(value: BarSeriesManager);
    /**
     * The valid items.
     */
    protected validItems: T[];
    /**
     * The dictionary which stores the index-inversion for the valid items
     */
    protected validItemsIndexInversion: Map<number, number>;
    /**
     * The label color.
     */
    labelColor: OxyColor;
    /**
     * The label margins.
     */
    labelMargin: number;
    /**
     * The label angle in degrees.
     */
    labelAngle: number;
    /**
     * Label placements.
     */
    labelPlacement: LabelPlacement;
    /**
     * Initializes a new instance of the BarSeriesBase class.
     */
    protected constructor(opt?: CreateBarSeriesBaseOptions);
    /**
     * Gets the list of items that should be rendered.
     */
    get actualItems(): T[];
    /**
     * Gets the items list.
     */
    items: T[];
    /**
     * Gets the actual width of the items of this series.
     * @returns The width.
     * The actual width is also influenced by the GapWidth of the CategoryAxis used by this series.
     */
    protected getActualBarWidth(): number;
    get categoryAxis(): CategoryAxis;
    /**
     * Gets the category axis.
     * @returns The category axis.
     */
    protected getCategoryAxis(): CategoryAxis;
    get valueAxis(): Axis | undefined;
    /**
     * Gets the item at the specified index.
     * @param i The index of the item.
     * @returns The item of the index.
     */
    protected getItem(i: number): any;
    /**
     * Gets a value indicating whether the specified item is valid.
     * @param item The items.
     * @returns true if the item is valid; false otherwise.
     */
    protected abstract isValid(item: T): boolean;
    /**
     * Updates the ItemsSourceItems from the ItemsSource and data fields.
     */
    protected abstract updateFromDataFields(): boolean;
    /**
     * Clears or creates the ItemsSourceItems list.
     */
    private clearItemsSourceItems;
    /**
     * Determines whether the specified axis is being used.
     * @param axis The axis.
     * @returns true if the axis is being used; false otherwise.
     * @internal
     */
    isUsing(axis: Axis): boolean;
    /**
     * Renders the item label.
     * @param rc The render context
     * @param item The item.
     * @param baseValue The bar item base value.
     * @param topValue The bar item top value.
     * @param categoryValue The bar item category value.
     * @param categoryEndValue The bar item category end value.
     * @param labelStringFormatter The formatter to use for the label.
     * @param labelValues An optional set of data values to use when generating label strings.
     */
    protected renderLabel(rc: IRenderContext, item: T, baseValue: number, topValue: number, categoryValue: number, categoryEndValue: number, labelStringFormatter: LabelStringFormatterType, ...labelValues: number[]): Promise<void>;
    /**
     * Updates the Max/Min limits of the axis.
     * @internal
     */
    updateAxisMaxMin(): void;
    /**
     * Updates the data.
     * @internal
     */
    updateData(): void;
    /**
     * Updates the valid data.
     */
    updateValidData(): void;
    protected getJsonIgnoreProperties(): string[];
}
//# sourceMappingURL=BarSeriesBase.d.ts.map