import { type CreateXYAxisSeriesOptions, EdgeRenderingMode, type IRenderContext, type LabelStringFormatterType, type OxyColor, type OxyRect, type PlotModelSerializeOptions, type ScreenPoint, TrackerHitResult, type TrackerStringFormatterType, XYAxisSeries } from '../..';
/**
 * Represents a rectangle item in a RectangleBarSeries.
 */
export interface RectangleBarItem {
    /**
     * The color.
     * If set to Automatic, the FillColor of the RectangleBarSeries will be used.
     */
    color: OxyColor;
    /**
     * The title.
     */
    title?: string;
    /**
     * The x0 coordinate.
     */
    x0: number;
    /**
     * The x1 coordinate.
     */
    x1: number;
    /**
     * The y0 coordinate.
     */
    y0: number;
    /**
     * The y1 coordinate.
     */
    y1: number;
}
export declare function createRectangleBarItem(x0: number, x1: number, y0: number, y1: number): RectangleBarItem;
export interface CreateRectangleBarSeriesOptions extends CreateXYAxisSeriesOptions {
    /**
     * The fill color.
     */
    fillColor?: OxyColor;
    /**
     * The stroke color.
     */
    strokeColor?: OxyColor;
    /**
     * The stroke thickness.
     */
    strokeThickness?: number;
    /**
     * The label string formatter.
     */
    labelStringFormatter?: LabelStringFormatterType;
    items?: RectangleBarItem[];
}
export declare const DefaultRectangleBarSeriesOptions: CreateRectangleBarSeriesOptions;
export declare const ExtendedDefaultRectangleBarSeriesOptions: {
    /**
     * The fill color.
     */
    fillColor?: string | undefined;
    /**
     * The stroke color.
     */
    strokeColor?: string | undefined;
    /**
     * The stroke thickness.
     */
    strokeThickness?: number | undefined;
    /**
     * The label string formatter.
     */
    labelStringFormatter?: LabelStringFormatterType | undefined;
    items?: RectangleBarItem[] | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('../..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: CreateXYAxisSeriesOptions;
};
/**
 * Represents a series for bar charts where the bars are defined by rectangles.
 */
export declare class RectangleBarSeries extends XYAxisSeries {
    /**
     * The default tracker formatter.
     */
    static readonly defaultTrackerStringFormatter: TrackerStringFormatterType;
    static readonly defaultLabelStringFormatter: (item: any, args: any) => string;
    /**
     * The default fill color.
     */
    private _defaultFillColor;
    /**
     * Initializes a new instance of the RectangleBarSeries class.
     */
    constructor(opt?: CreateRectangleBarSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the default color of the interior of the rectangles.
     */
    fillColor: OxyColor;
    /**
     * Gets the actual fill color.
     */
    get actualFillColor(): OxyColor;
    private _items;
    /**
     * Gets the rectangle bar items.
     */
    get items(): RectangleBarItem[];
    /**
     * Gets or sets the formatter for the labels.
     */
    labelStringFormatter: LabelStringFormatterType;
    /**
     * Gets or sets the color of the border around the rectangles.
     */
    strokeColor: OxyColor;
    /**
     * Gets or sets the thickness of the border around the rectangles.
     */
    strokeThickness: number;
    /**
     * Gets or sets the actual rectangles for the rectangles.
     */
    protected actualBarRectangles: OxyRect[];
    /**
     * Gets or sets the actual rectangle bar items.
     */
    protected actualItems: RectangleBarItem[];
    /**
     * Gets the point in the dataset that is nearest the specified point.
     * @param point The point.
     * @param interpolate Specifies whether to interpolate or not.
     * @returns A TrackerHitResult for the current hit.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Renders the series on the specified render context.
     * @param rc The render context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Renders the legend symbol on the specified rendering context.
     * @param rc The rendering context.
     * @param legendBox The legend rectangle.
     */
    renderLegend(rc: IRenderContext, legendBox: OxyRect): Promise<void>;
    /**
     * Sets the default values.
     * @internal
     */
    setDefaultValues(): void;
    /**
     * Updates the data.
     * @internal
     */
    updateData(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Checks if the specified value is valid.
     * @param v The value.
     * @returns True if the value is valid.
     */
    protected isValid(v: number): boolean;
    protected getElementDefaultValues(): any;
    toJSON(opt?: PlotModelSerializeOptions): any;
}
//# sourceMappingURL=RectangleBarSeries.d.ts.map