import { type BarItemBase, BarSeriesBase, type CreateBarSeriesBaseOptions, EdgeRenderingMode, type IRenderContext, type LabelStringFormatterType, type OxyColor, type OxyRect, type ScreenPoint, TrackerHitResult, type TrackerStringFormatterType } from '../..';
export interface TornadoBarItem extends BarItemBase {
    /**
     * The base value.
     */
    baseValue: number;
    /**
     * The maximum value.
     */
    maximum: number;
    /**
     * The color for the maximum bar.
     */
    maximumColor: OxyColor;
    /**
     * The minimum value.
     */
    minimum: number;
    /**
     * The color for the minimum bar.
     */
    minimumColor: OxyColor;
}
export declare function newTornadoBarItem(item: Partial<TornadoBarItem>): TornadoBarItem & Partial<TornadoBarItem>;
export declare function isTornadoBarItem(item: any): item is TornadoBarItem;
export interface CreateTornadoBarSeriesOptions extends CreateBarSeriesBaseOptions {
    baseField?: string;
    baseValue?: number;
    maximumColorField?: string;
    maximumField?: string;
    maximumFillColor?: OxyColor;
    maximumLabelStringFormatter?: LabelStringFormatterType;
    minimumColorField?: string;
    minimumField?: string;
    minimumFillColor?: OxyColor;
    minimumLabelStringFormatter?: LabelStringFormatterType;
    actualMaximumBarRectangles?: OxyRect[];
    actualMinimumBarRectangles?: OxyRect[];
}
export declare const DefaultTornadoBarSeriesOptions: CreateTornadoBarSeriesOptions;
export declare const ExtendedDefaultTornadoBarSeriesOptions: {
    baseField?: string | undefined;
    baseValue?: number | undefined;
    maximumColorField?: string | undefined;
    maximumField?: string | undefined;
    maximumFillColor?: string | undefined;
    maximumLabelStringFormatter?: LabelStringFormatterType | undefined;
    minimumColorField?: string | undefined;
    minimumField?: string | undefined;
    minimumFillColor?: string | undefined;
    minimumLabelStringFormatter?: LabelStringFormatterType | undefined;
    actualMaximumBarRectangles?: OxyRect[] | undefined;
    actualMinimumBarRectangles?: OxyRect[] | undefined;
    barWidth?: number | undefined;
    strokeColor?: string | undefined;
    strokeThickness?: number | undefined;
    labelColor?: string | undefined;
    labelMargin?: number | undefined;
    labelAngle?: number | undefined;
    labelPlacement?: import('../..').LabelPlacement | undefined;
    labelStringFormatter?: LabelStringFormatterType | undefined;
    items?: BarItemBase[] | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('../..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('../..').CreateXYAxisSeriesOptions;
};
/**
 * Represents a series that can be used to create tornado plots.
 * See http://en.wikipedia.org/wiki/Tornado_diagram.
 */
export declare class TornadoBarSeries extends BarSeriesBase<TornadoBarItem> {
    /**
     * The default tracker formatter
     */
    static readonly defaultTrackerStringFormatter: TrackerStringFormatterType;
    static readonly defaultMinimumLabelStringFormatter: LabelStringFormatterType;
    static readonly defaultMaximumLabelStringFormatter: LabelStringFormatterType;
    /**
     * The default fill color.
     */
    private _defaultMaximumFillColor;
    /**
     * The default minimum fill color.
     */
    private _defaultMinimumFillColor;
    /**
     * Initializes a new instance of the TornadoBarSeries class.
     */
    constructor(opt?: CreateTornadoBarSeriesOptions);
    getElementName(): string;
    /**
     * Gets the actual fill color.
     */
    get actualMaximumFillColor(): OxyColor;
    /**
     * Gets the actual minimum fill color.
     */
    get actualMinimumFillColor(): OxyColor;
    /**
     * Gets or sets the color field.
     */
    baseField?: string;
    /**
     * Gets or sets the base value.
     */
    baseValue: number;
    /**
     * Gets or sets the color field.
     */
    maximumColorField?: string;
    /**
     * Gets or sets the color field.
     */
    maximumField?: string;
    /**
     * Gets or sets the color of the interior of the Maximum bars.
     */
    maximumFillColor: OxyColor;
    /**
     * Gets or sets the formatter for the maximum labels.
     */
    maximumLabelStringFormatter: LabelStringFormatterType;
    /**
     * Gets or sets the color field.
     */
    minimumColorField?: string;
    /**
     * Gets or sets the color field.
     */
    minimumField?: string;
    /**
     * Gets or sets the default color of the interior of the Minimum bars.
     */
    minimumFillColor: OxyColor;
    /**
     * Gets or sets the formatter for the minimum labels.
     */
    minimumLabelStringFormatter: LabelStringFormatterType;
    /**
     * Gets or sets the actual rectangles for the maximum bars.
     */
    protected actualMaximumBarRectangles: OxyRect[];
    /**
     * Gets or sets the actual rectangles for the minimum bars.
     */
    protected actualMinimumBarRectangles: OxyRect[];
    /**
     * Gets the nearest point.
     * @param point The point.
     * @param interpolate Whether to interpolate.
     * @returns The nearest point.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Renders the series on the specified render context.
     * @param rc The render context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Renders the legend on the specified render context.
     * @param rc The render context.
     * @param legendBox The legend box.
     */
    renderLegend(rc: IRenderContext, legendBox: OxyRect): Promise<void>;
    /**
     * Sets the default values.
     * @internal
     */
    setDefaultValues(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Checks if the specified item is valid.
     * @param item The item to check.
     * @returns true if the item is valid; false otherwise.
     */
    protected isValid(item: TornadoBarItem): boolean;
    /**
     * Updates the ItemsSourceItems from the ItemsSource and data fields.
     * @returns true if the update was successful; false otherwise.
     */
    protected updateFromDataFields(): boolean;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=TornadoBarSeries.d.ts.map