import { type CreateXYAxisSeriesOptions, type DataPoint, type IRenderContext, type LabelStringFormatterType, LineStyle, type OxyColor, type ScreenPoint, TrackerHitResult, type TrackerStringFormatterArgs, XYAxisSeries } from '..';
export interface CreateContourSeriesOptions extends CreateXYAxisSeriesOptions {
    columnCoordinates?: number[];
    rowCoordinates?: number[];
    contourLevelStep?: number;
    contourLevels?: number[];
    contourColors?: OxyColor[];
    data?: number[][];
    labelBackground?: OxyColor;
    labelStringFormatter?: LabelStringFormatterType;
    labelSpacing?: number;
    labelStep?: number;
    lineStyle?: LineStyle;
    minimumSegmentLength?: number;
    multiLabel?: boolean;
    strokeThickness?: number;
    color?: OxyColor;
    trackerStringFormatter?: ContourSeriesTrackerStringFormatterType;
}
export declare const DefaultContourSeriesOptions: CreateContourSeriesOptions;
export declare const ExtendedDefaultContourSeriesOptions: {
    columnCoordinates?: number[] | undefined;
    rowCoordinates?: number[] | undefined;
    contourLevelStep?: number | undefined;
    contourLevels?: number[] | undefined;
    contourColors?: string[] | undefined;
    data?: number[][] | undefined;
    labelBackground?: string | undefined;
    labelStringFormatter?: LabelStringFormatterType | undefined;
    labelSpacing?: number | undefined;
    labelStep?: number | undefined;
    lineStyle?: LineStyle | undefined;
    minimumSegmentLength?: number | undefined;
    multiLabel?: boolean | undefined;
    strokeThickness?: number | undefined;
    color?: string | undefined;
    trackerStringFormatter?: ContourSeriesTrackerStringFormatterType | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: CreateXYAxisSeriesOptions;
};
export interface ContourSeriesTrackerStringFormatterArgs extends TrackerStringFormatterArgs {
    item?: Contour;
    contourLevel?: number;
}
export type ContourSeriesTrackerStringFormatterType = (args: ContourSeriesTrackerStringFormatterArgs) => string | undefined;
/**
 * Represents a series that renders contours.
 */
export declare class ContourSeries extends XYAxisSeries {
    /**
     * The default tracker formatter
     */
    static readonly DefaultTrackerFormatString: ContourSeriesTrackerStringFormatterType;
    getElementName(): string;
    /**
     * The contour collection.
     */
    private _contours?;
    /**
     * The temporary segment collection.
     */
    private _segments;
    /**
     * The default color.
     */
    private _defaultColor;
    /**
     * The color.
     */
    color: OxyColor;
    /**
     * The column coordinates.
     */
    columnCoordinates: number[];
    /**
     * The contour level step size.
     */
    contourLevelStep: number;
    /**
     * The contour levels.
     */
    contourLevels?: number[];
    /**
     * The contour colors.
     */
    contourColors: OxyColor[];
    /**
     * The data.
     */
    data?: number[][];
    /**
     * The text background color.
     */
    labelBackground: OxyColor;
    /**
     * The formatter for contour values.
     */
    labelStringFormatter?: LabelStringFormatterType;
    /**
     * A format function used for the tracker. The default depends on the series.
     * The arguments for the formatter may be different for each type of series. See the documentation.
     */
    trackerStringFormatter?: ContourSeriesTrackerStringFormatterType;
    /**
     * The label spacing.
     */
    labelSpacing: number;
    /**
     * Multiple labels should be displayed per Contour.
     */
    multiLabel: boolean;
    /**
     * The interval between labeled contours.
     */
    labelStep: number;
    /**
     * The line style.
     */
    lineStyle: LineStyle;
    /**
     * The row coordinates.
     */
    rowCoordinates: number[];
    /**
     * The stroke thickness.
     */
    strokeThickness: number;
    /**
     * The minimum length of the segment.
     */
    minimumSegmentLength: number;
    constructor(opt?: CreateContourSeriesOptions);
    /**
     * Gets the actual color.
     */
    get actualColor(): OxyColor;
    /**
     * Calculates the contours.
     */
    calculateContours(): void;
    /**
     * Gets the point in the dataset that is nearest the specified point.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Renders the series on the specified rendering context.
     * @param rc The rendering context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Sets default values from the plot model.
     * @internal
     */
    setDefaultValues(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Gets the index of item that is closest to the specified value.
     * @param values A list of values.
     * @param value A value.
     * @returns An index.
     */
    private static indexOf;
    /**
     * The add contour labels.
     * @param contour The contour.
     * @param pts The points of the contour.
     * @param contourLabels The contour labels.
     * @param labelIndex The index of the point in the list of points, where the label should get added.
     */
    private addContourLabels;
    /**
     * Joins the contour segments.
     * @param epsFactor The tolerance for segment ends to connect (maximum allowed [length of distance vector] / [length of position vector]).
     */
    private joinContourSegments;
    /**
     * Renders the contour label.
     * @param rc The render context.
     * @param cl The contour label.
     */
    private renderLabel;
    /**
     * Renders the contour label background.
     * @param rc The render context.
     * @param cl The contour label.
     */
    private renderLabelBackground;
    protected getElementDefaultValues(): any;
}
/**
 * Represents a contour.
 */
declare class Contour {
    /**
     * The contour level.
     */
    readonly contourLevel: number;
    /**
     * The points.
     */
    readonly points: DataPoint[];
    /**
     * The color of the contour.
     */
    color: OxyColor;
    /**
     * Initializes a new instance of the Contour class.
     * @param points The points.
     * @param contourLevel The contour level.
     */
    constructor(points: DataPoint[], contourLevel: number);
}
export {};
//# sourceMappingURL=ContourSeries.d.ts.map