import { type CreateHighLowSeriesOptions, type HighLowItem, HighLowSeries, type IRenderContext, LineJoin, LineStyle, type OxyColor, type OxyRect, type ScreenPoint, TrackerHitResult } from '../..';
export interface CreateCandleStickSeriesOptions extends CreateHighLowSeriesOptions {
    /**
     * Gets or sets the color used when the closing value is greater than opening value.
     */
    increasingColor?: OxyColor;
    /**
     * Gets or sets the fill color used when the closing value is less than opening value.
     */
    decreasingColor?: OxyColor;
    /**
     * Gets or sets the bar width in data units (for example if the X axis is date/time based, then should
     * use the difference of DateTimeAxis.toDouble(date) to indicate the width).  By default, candlestick
     * series will use 0.80 x the minimum difference in data points.
     */
    candleWidth?: number;
}
export declare const DefaultCandleStickSeriesOptions: CreateCandleStickSeriesOptions;
export declare const ExtendedDefaultCandleStickSeriesOptions: {
    color?: string | undefined;
    dataFieldClose?: string | undefined;
    dataFieldHigh?: string | undefined;
    dataFieldLow?: string | undefined;
    dataFieldOpen?: string | undefined;
    dataFieldX?: string | undefined;
    lineJoin?: LineJoin | undefined;
    lineStyle?: LineStyle | undefined;
    strokeThickness?: number | undefined;
    tickLength?: number | undefined;
    trackerStringFormatter?: import('../..').TrackerStringFormatterType | import('../..').HighLowSeriesTrackerStringFormatterType | undefined;
    items?: HighLowItem[] | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('../..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('../..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('../..').CreateXYAxisSeriesOptions;
    /**
     * Gets or sets the color used when the closing value is greater than opening value.
     */
    increasingColor?: string | undefined;
    /**
     * Gets or sets the fill color used when the closing value is less than opening value.
     */
    decreasingColor?: string | undefined;
    /**
     * Gets or sets the bar width in data units (for example if the X axis is date/time based, then should
     * use the difference of DateTimeAxis.toDouble(date) to indicate the width).  By default, candlestick
     * series will use 0.80 x the minimum difference in data points.
     */
    candleWidth?: number | undefined;
};
/**
 * Represents a "higher performance" ordered OHLC series for candlestick charts
 * Does the following:
 * - automatically calculates the appropriate bar width based on available screen + # of bars
 * - can render and pan within millions of bars, using a fast approach to indexing in series
 * - convenience methods
 * This implementation is associated with issue https://github.com/oxyplot/oxyplot/issues/369.
 * See also Wikipedia and Matlab documentation
 * http://en.wikipedia.org/wiki/Candlestick_chart
 * http://www.mathworks.com/help/toolbox/finance/candle.html
 */
export declare class CandleStickSeries extends HighLowSeries {
    /**
     * The minimum X gap between successive data items
     */
    private _minDx;
    /**
     * Initializes a new instance of the CandleStickSeries class.
     */
    constructor(opt?: CreateCandleStickSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the color used when the closing value is greater than opening value.
     */
    increasingColor: OxyColor;
    /**
     * Gets or sets the fill color used when the closing value is less than opening value.
     */
    decreasingColor: OxyColor;
    /**
     * Gets or sets the bar width in data units (for example if the X axis is date/time based, then should
     * use the difference of DateTimeAxis.toDouble(date) to indicate the width).  By default, candlestick
     * series will use 0.80 x the minimum difference in data points.
     */
    candleWidth: number;
    /**
     * Fast index of bar where max(bar[i].X) <= x
     * @returns The index of the bar closest to X, where max(bar[i].X) <= x.
     * @param x The x coordinate.
     * @param startIndex starting index
     */
    findByX(x: number, startIndex?: number): number;
    /**
     * Renders the series on the specified render context.
     * @param rc The render context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Renders the legend symbol for the series on the specified rendering context.
     * @param rc The rendering context.
     * @param legendBox The bounding rectangle of the legend box.
     */
    renderLegend(rc: IRenderContext, legendBox: OxyRect): Promise<void>;
    /**
     * Gets the point on the series that is nearest the specified point.
     * @param point The point.
     * @param interpolate Interpolate the series if this flag is set to true.
     * @returns A TrackerHitResult for the current hit.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Updates the data.
     * @internal
     */
    updateData(): void;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=CandleStickSeries.d.ts.map