import { type CreateXYAxisSeriesOptions, type IColorAxis, type IRenderContext, type LabelStringFormatterType, type OxyRect, type ScreenPoint, TrackerHitResult, type TrackerStringFormatterType, XYAxisSeries } from '..';
/**
 * Specifies how the heat map coordinates are defined.
 */
export declare enum HeatMapCoordinateDefinition {
    /**
     * The coordinates define the center of the cells
     */
    Center = 0,
    /**
     * The coordinates define the edge of the cells
     */
    Edge = 1
}
/**
 * Specifies how the heat map is rendered.
 */
export declare enum HeatMapRenderMethod {
    /**
     * The heat map is rendered as a bitmap
     */
    Bitmap = 0,
    /**
     * The heat map is rendered as a collection of discrete rectangles
     */
    Rectangles = 1
}
export interface CreateHeatMapSeriesOptions extends CreateXYAxisSeriesOptions {
    x0?: number;
    x1?: number;
    y0?: number;
    y1?: number;
    data?: number[][];
    interpolate?: boolean;
    colorAxis?: IColorAxis;
    colorAxisKey?: string;
    coordinateDefinition?: HeatMapCoordinateDefinition;
    renderMethod?: HeatMapRenderMethod;
    labelStringFormatter?: LabelStringFormatterType;
    labelFontSize?: number;
}
export declare const DefaultHeatMapSeriesOptions: CreateHeatMapSeriesOptions;
export declare const ExtendedDefaultHeatMapSeriesOptions: {
    x0?: number | undefined;
    x1?: number | undefined;
    y0?: number | undefined;
    y1?: number | undefined;
    data?: number[][] | undefined;
    interpolate?: boolean | undefined;
    colorAxis?: IColorAxis | undefined;
    colorAxisKey?: string | undefined;
    coordinateDefinition?: HeatMapCoordinateDefinition | undefined;
    renderMethod?: HeatMapRenderMethod | undefined;
    labelStringFormatter?: LabelStringFormatterType | undefined;
    labelFontSize?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: CreateXYAxisSeriesOptions;
};
/**
 * Represents a heat map.
 */
export declare class HeatMapSeries extends XYAxisSeries {
    /**
     * The default tracker formatter
     */
    static readonly DefaultTrackerFormatString: TrackerStringFormatterType;
    /**
     * The default color-axis title
     */
    private static readonly DefaultColorAxisTitle;
    /**
     * The hash code of the data when the image was updated.
     */
    private _dataHash;
    /**
     * The hash code of the color axis when the image was updated.
     */
    private _colorAxisHash;
    /**
     * The image
     */
    private _image?;
    /**
     * Initializes a new instance of the HeatMapSeries class.
     */
    constructor(opt?: CreateHeatMapSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the x-coordinate of the elements at index [0,*] in the data set.
     */
    x0: number;
    /**
     * Gets or sets the x-coordinate of the mid-point for the elements at index [m-1,*] in the data set.
     */
    x1: number;
    /**
     * Gets or sets the y-coordinate of the mid-point for the elements at index [*,0] in the data set.
     */
    y0: number;
    /**
     * Gets or sets the y-coordinate of the mid-point for the elements at index [*,n-1] in the data set.
     */
    y1: number;
    /**
     * Gets or sets the data array.
     */
    data?: number[][];
    /**
     * Gets or sets a value indicating whether to interpolate when rendering. The default value is true.
     */
    interpolate: boolean;
    /**
     * Gets the minimum value of the dataset.
     */
    get minValue(): number;
    private _minValue;
    /**
     * Gets the maximum value of the dataset.
     */
    get maxValue(): number;
    private _maxValue;
    /**
     * Gets the color axis.
     */
    get colorAxis(): IColorAxis | undefined;
    protected set colorAxis(value: IColorAxis | undefined);
    private _colorAxis?;
    /**
     * Gets or sets the color axis key.
     */
    colorAxisKey?: string;
    /**
     * Gets or sets the coordinate definition. The default value is HeatMapCoordinateDefinition.Center.
     */
    coordinateDefinition: HeatMapCoordinateDefinition;
    /**
     * Gets or sets the render method. The default value is HeatMapRenderMethod.Bitmap.
     */
    renderMethod: HeatMapRenderMethod;
    /**
     * Gets or sets the formatter for the cell labels. The default value is "0.00".
     */
    labelStringFormatter: LabelStringFormatterType;
    /**
     * Gets or sets the font size of the labels. The default value is 0 (labels not visible).
     */
    labelFontSize: number;
    /**
     * Invalidates the image that renders the heat map. The image will be regenerated the next time the HeatMapSeries is rendered.
     * Call PlotModel.invalidatePlot to refresh the view.
     */
    invalidate(): void;
    /**
     * Renders the series on the specified render context.
     * @param rc The rendering context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Gets the point on the series that is nearest the specified point.
     * @param point The point.
     * @param interpolate Interpolate the series if this flag is set to true.
     * @returns A TrackerHitResult for the current hit.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Ensures that the axes of the series is defined.
     * @internal
     */
    ensureAxes(): void;
    /**
     * Updates the maximum and minimum values of the series for the x and y dimensions only.
     * @internal
     */
    updateMaxMinXY(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Updates the axes to include the max and min of this series.
     * @internal
     */
    updateAxisMaxMin(): void;
    /**
     * Renders the labels.
     * @param rc The IRenderContext
     * @param rect The bounding rectangle for the data.
     */
    protected renderLabels(rc: IRenderContext, rect: OxyRect): Promise<void>;
    /**
     * Gets the label for the specified cell.
     * @param v The value of the cell.
     * @param i The first index.
     * @param j The second index.
     * @returns The label string.
     */
    protected getLabel(v: number, i: number, j: number): string;
    /**
     * Gets the interpolated value at the specified position in the data array (by bilinear interpolation).
     * Where interpolation is impossible, return NaN, rather than a calculated nonsense value.
     * @param data The data.
     * @param i The first index.
     * @param j The second index.
     * @returns The interpolated value.
     */
    private static getValue;
    /**
     * Tests if a DataPoint is inside the heat map
     * @param p The DataPoint to test.
     * @returns True if the point is inside the heat map.
     */
    private isPointInRange;
    /**
     * Updates the image.
     */
    private updateImage;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=HeatMapSeries.d.ts.map