import { type CreateXYAxisSeriesOptions, type DataPoint, DataVector, EdgeRenderingMode, type IRenderContext, LabelPlacement, type LabelStringFormatterType, type OxyColor, type OxyRect, type ScreenPoint, TrackerHitResult, type TrackerStringFormatterArgs, XYAxisSeries } from '..';
/** Represents an item in a HistogramSeries, a bin (range) and its area. */
export interface HistogramItem {
    /** The range start. */
    rangeStart: number;
    /** The range end. */
    rangeEnd: number;
    /** The area. */
    area: number;
    /** The count. */
    count: number;
    value?: number;
    /** The color. */
    color: OxyColor;
}
export declare function newHistogramItem(rangeStart: number, rangeEnd: number, area: number, count: number, color?: OxyColor): HistogramItem;
export declare class HistogramItemEx implements HistogramItem {
    private readonly _item;
    constructor(item: HistogramItem);
    static from(item: HistogramItem): HistogramItemEx;
    get rangeStart(): number;
    get rangeEnd(): number;
    get area(): number;
    get count(): number;
    get color(): string;
    get center(): number;
    get width(): number;
    get height(): number;
    get value(): number;
    contains(p: DataPoint): boolean;
}
export declare function isHistogramItem(obj: any): boolean;
export interface HistogramSeriesTrackerStringFormatterArgs extends TrackerStringFormatterArgs {
    readonly item?: HistogramItem;
    readonly itemDirection?: DataVector;
}
export type HistogramSeriesTrackerStringFormatterType = (args: HistogramSeriesTrackerStringFormatterArgs) => string | undefined;
export interface CreateHistogramSeriesOptions extends CreateXYAxisSeriesOptions {
    baseValue?: number;
    baseLine?: number;
    fillColor?: OxyColor;
    strokeColor?: OxyColor;
    negativeFillColor?: OxyColor;
    negativeStrokeColor?: OxyColor;
    strokeThickness?: number;
    labelStringFormatter?: LabelStringFormatterType;
    labelMargin?: number;
    labelPlacement?: LabelPlacement;
    colorMapping?: (item: HistogramItem) => OxyColor;
    mapping?: (item: any) => HistogramItem;
    trackerStringFormatter?: HistogramSeriesTrackerStringFormatterType;
    items?: HistogramItem[];
}
export declare const DefaultHistogramSeriesOptions: CreateHistogramSeriesOptions;
export declare const ExtendedDefaultHistogramSeriesOptions: {
    baseValue?: number | undefined;
    baseLine?: number | undefined;
    fillColor?: string | undefined;
    strokeColor?: string | undefined;
    negativeFillColor?: string | undefined;
    negativeStrokeColor?: string | undefined;
    strokeThickness?: number | undefined;
    labelStringFormatter?: LabelStringFormatterType | undefined;
    labelMargin?: number | undefined;
    labelPlacement?: LabelPlacement | undefined;
    colorMapping?: ((item: HistogramItem) => OxyColor) | undefined;
    mapping?: ((item: any) => HistogramItem) | undefined;
    trackerStringFormatter?: import('..').TrackerStringFormatterType | HistogramSeriesTrackerStringFormatterType | undefined;
    items?: HistogramItem[] | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: CreateXYAxisSeriesOptions;
};
/** Represents a series that can be bound to a collection of HistogramItem. */
export declare class HistogramSeries extends XYAxisSeries {
    /**
     * The default tracker formatter.
     */
    static readonly defaultTrackerStringFormatter: HistogramSeriesTrackerStringFormatterType;
    /**
     * The default fill color.
     */
    private _defaultFillColor;
    /**
     * The items originating from the items source.
     */
    private _actualItems?;
    /**
     * Initializes a new instance of the HistogramSeries class.
     */
    constructor(opt?: CreateHistogramSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the base value. Default value is 0.
     */
    baseValue: number;
    /**
     * Gets or sets the base value.
     */
    baseLine: number;
    private _actualBaseLine;
    /**
     * Gets or sets the actual baseline.
     */
    get actualBaseLine(): number;
    /**
     * Gets or sets the color of the interior of the bars.
     */
    fillColor: OxyColor;
    /**
     * Gets the actual fill color.
     */
    get actualFillColor(): OxyColor;
    /**
     * Gets or sets the color of the border around the bars.
     */
    strokeColor: OxyColor;
    /**
     * Gets or sets the color of the interior of the bars when the value is negative.
     */
    negativeFillColor: OxyColor;
    /**
     * Gets or sets the color of the border around the bars when the value is negative.
     */
    negativeStrokeColor: OxyColor;
    /**
     * Gets or sets the thickness of the bar border strokes.
     */
    strokeThickness: number;
    /**
     * Gets the minimum value of the dataset.
     */
    get minValue(): number;
    private _minValue;
    /**
     * Gets the maximum value of the dataset.
     */
    get maxValue(): number;
    private _maxValue;
    /**
     * Gets or sets the formatter for the cell labels. The default value is 0.00.
     */
    labelStringFormatter?: LabelStringFormatterType;
    /**
     * A format function used for the tracker. The default depends on the series.
     * The arguments for the formatter may be different for each type of series. See the documentation.
     */
    trackerStringFormatter?: HistogramSeriesTrackerStringFormatterType;
    /**
     * Gets or sets the label margins.
     */
    labelMargin: number;
    /**
     * Gets or sets label placements.
     */
    labelPlacement: LabelPlacement;
    /**
     * Gets or sets the delegate used to map from histogram item to color.
     */
    colorMapping: (item: HistogramItem) => OxyColor;
    /**
     * Gets or sets the delegate used to map from ItemsSeries.ItemsSource to HistogramSeries. The default is null.
     */
    mapping?: (item: any) => HistogramItem;
    /**
     * Gets the list of HistogramItem.
     */
    items: HistogramItem[];
    /**
     * Gets the list of HistogramItem that should be rendered.
     */
    protected get actualItems(): HistogramItem[];
    /** Renders the series on the specified rendering context. */
    render(rc: IRenderContext): Promise<void>;
    /** Gets the point on the series that is nearest the specified point. */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /** Renders the legend symbol on the specified rendering context. */
    renderLegend(rc: IRenderContext, legendBox: OxyRect): Promise<void>;
    /**
     * Updates the data.
     * @internal
     * */
    updateData(): void;
    /**
     * Sets the default values.
     * @internal
     * */
    setDefaultValues(): void;
    /**
     * Updates the axes to include the max and min of this series.
     * @internal
     * */
    updateAxisMaxMin(): void;
    /** Computes the baseline. */
    protected computeActualBaseLine(): void;
    /**
     * Updates the maximum and minimum values of the series for the x and y dimensions only.
     * @internal
     * */
    updateMaxMinXY(): void;
    /**
     * Updates the internal maximum and minimum values of the series.
     */
    updateMaxMin(): void;
    /**
     * Gets the item at the specified index.
     * @param i The index of the item.
     * @returns The item at the specified index.
     */
    protected getItem(i: number): object | undefined;
    /**
     * Renders the histogram bins as rectangles with optional fill and stroke.
     * @param rc The rendering context.
     * @param items The histogram items to render.
     */
    protected renderBins(rc: IRenderContext, items: HistogramItem[]): Promise<void>;
    /**
     * Gets the fill color of the given histogram item.
     * @param item The histogram item.
     * @returns The fill color of the item.
     */
    protected getItemFillColor(item: HistogramItem): OxyColor;
    /**
     * Gets the stroke color of the given histogram item.
     * @param item The histogram item.
     * @returns The stroke color of the item.
     */
    protected getItemStrokeColor(item: HistogramItem): OxyColor;
    /**
     * Renders the label for the given histogram item.
     * @param rc The render context.
     * @param rect The rectangle representing the histogram bin.
     * @param item The histogram item.
     */
    protected renderLabel(rc: IRenderContext, rect: OxyRect, item: HistogramItem): Promise<void>;
    /**
     * Determines if a DataPoint falls within the histogram bounds.
     * @param p The DataPoint to test.
     * @returns True if the point is inside the histogram.
     */
    private isPointInRange;
    /**
     * Initializes or clears the actual items list.
     */
    private clearActualItems;
    /**
     * Gets the default color for a histogram item based on its value.
     * @param item The histogram item.
     * @returns The default color.
     */
    private getDefaultColor;
    /**
     * Updates the actual items based on the ItemsSource.
     */
    private updateActualItems;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=HistogramSeries.d.ts.map