import { type CreateXYAxisSeriesOptions, type DataPoint, EdgeRenderingMode, type IColorAxis, type IRenderContext, type LabelStringFormatterType, type OxyColor, type OxyRect, type ScreenPoint, TrackerHitResult, type TrackerStringFormatterType, XYAxisSeries } from '..';
export interface PolygonItem {
    outlines: DataPoint[][];
    value: number;
    bounds: OxyRect[];
}
export interface CreatePolygonSeriesOptions extends CreateXYAxisSeriesOptions {
    stroke?: OxyColor;
    strokeThickness?: number;
    items?: PolygonItem[];
    mapping?: (item: any) => PolygonItem;
    colorAxisKey?: string;
    labelFontSize?: number;
    labelStringFormatter?: LabelStringFormatterType;
}
export declare const DefaultPolygonSeriesOptions: CreatePolygonSeriesOptions;
export declare const ExtendedDefaultPolygonSeriesOptions: {
    stroke?: string | undefined;
    strokeThickness?: number | undefined;
    items?: PolygonItem[] | undefined;
    mapping?: ((item: any) => PolygonItem) | undefined;
    colorAxisKey?: string | undefined;
    labelFontSize?: number | undefined;
    labelStringFormatter?: LabelStringFormatterType | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: CreateXYAxisSeriesOptions;
};
/**
 * Represents a series that can be bound to a collection of PolygonItem.
 */
export declare class PolygonSeries extends XYAxisSeries {
    /**
     * The default tracker formatter
     */
    private static readonly defaultTrackerStringFormatter;
    /** The default color-axis title */
    private static readonly _defaultColorAxisTitle;
    /**
     * The items originating from the items source.
     */
    private _actualItems;
    /** Gets the list of Polygons that should be rendered. */
    get actualItems(): PolygonItem[];
    /**
     * Gets the minimum value of the dataset.
     */
    get minValue(): number;
    private _minValue;
    /**
     * Gets the maximum value of the dataset.
     */
    get maxValue(): number;
    private _maxValue;
    private _colorAxis?;
    /**
     * Gets the color axis.
     */
    get colorAxis(): IColorAxis | undefined;
    /**
     * Gets or sets the color axis key.
     */
    colorAxisKey?: string;
    /**
     * Gets or sets the formatter for the cell labels. The default value is `0.00`.
     *
     * The label formatter is only used when `LabelFontSize` is greater than 0.
     */
    labelStringFormatter: LabelStringFormatterType;
    /**
     * Gets or sets the font size of the labels. The default value is 0 (labels not visible).
     *
     * The font size is relative to the cell height.
     */
    labelFontSize: number;
    /**
     * Gets or sets the delegate used to map from `ItemsSource` to `PolygonItem`. The default is `null`.
     */
    mapping?: (item: any) => PolygonItem;
    /**
     * Gets or sets the list of Polygons.
     *
     * This list is used if `ItemsSource` is not set.
     */
    items: PolygonItem[];
    /**
     * Gets or sets the stroke. The default is `OxyColors.Undefined`.
     */
    stroke: OxyColor;
    /**
     * Gets or sets the stroke thickness. The default is 2.
     */
    strokeThickness: number;
    constructor(opt?: CreatePolygonSeriesOptions);
    getElementName(): string;
    /**
     * Renders the series on the specified rendering context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Updates the data.
     * @internal
     */
    updateData(): void;
    /**
     * Gets the item at the specified index.
     *
     * @param i The index of the item.
     * @returns The item of the index.
     */
    protected getItem(i: number): any;
    /**
     * Clears or creates the `actualItems` list.
     */
    private clearActualItems;
    /**
     * Updates the points from the `ItemsSource`.
     */
    private updateActualItems;
    /**
     * Renders the points as line, broken line and markers.
     */
    protected renderPolygons(rc: IRenderContext, items: PolygonItem[]): Promise<void>;
    /**
     * Gets the point on the series that is nearest the specified point.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Ensures that the axes of the series is defined.
     * @internal
     */
    ensureAxes(): void;
    /**
     * Updates the maximum and minimum values of the series for the x and y dimensions only.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateAxisMaxMin(): void;
    /**
     * Updates the axes to include the max and min of this series.
     * @internal
     */
    updateMaxMinXY(): void;
    /**
     * Tests if a `DataPoint` is inside the heat map.
     */
    private isPointInRange;
    protected getElementDefaultValues(): any;
}
export declare function newPolygonItem(outlines: DataPoint[] | DataPoint[][], value: number): PolygonItem;
//# sourceMappingURL=PolygonSeries.d.ts.map