import { type CreateXYAxisSeriesOptions, type DataPoint, type IColorAxis, type IRenderContext, type LabelStringFormatterType, type ScreenPoint, TrackerHitResult, type TrackerStringFormatterType, XYAxisSeries } from '..';
/**
 * Represents an item in a RectangleSeries.
 * RectangleItems are transformed to OxyRects.
 */
export interface RectangleItem {
    /**
     * Gets the first data point.
     */
    a: DataPoint;
    /**
     * Gets the diagonally-opposite data point.
     */
    b: DataPoint;
    /**
     * Gets the value of the item.
     */
    value: number;
}
/**
 * Initializes a new instance of the RectangleItem class.
 * @param x1 The x coordinate of the first corner.
 * @param x2 The x coordinate of the diagonally-opposite corner.
 * @param y1 The y coordinate of the first corner.
 * @param y2 The y coordinate of the diagonally-opposite corner.
 * @param value The value of the data rect.
 */
export declare function newRectangleItem(x1: number, x2: number, y1: number, y2: number, value: number): RectangleItem;
/**
 * Initializes a new instance of the RectangleItem class.
 * @param a The first corner.
 * @param b The diagonally-opposite corner.
 * @param value The value of the data rect.
 */
export declare function newRectangleItem(a: DataPoint, b: DataPoint, value: number): RectangleItem;
/**
 * The undefined rectangle item.
 */
export declare const RectangleItem_Undefined: RectangleItem;
/**
 * Determines whether the specified point lies within the boundary of the rectangle.
 * @returns true if the value of the p parameter is inside the bounds of this instance.
 */
export declare function rectangleItemContains(item: RectangleItem, p: DataPoint): boolean;
export declare function isRectangleItem(obj: any): boolean;
export interface CreateRectangleSeriesOptions extends CreateXYAxisSeriesOptions {
    /**
     * The items originating from the items source.
     */
    items?: RectangleItem[];
    /**
     * The delegate used to map from ItemsSeries.itemsSource to RectangleItem. The default is null.
     */
    mapping?: (item: any) => RectangleItem;
    /**
     * The color axis key.
     */
    colorAxisKey?: string;
    /**
     * The formatter for the cell labels. The default value is 0.00.
     */
    labelStringFormatter?: LabelStringFormatterType;
    /**
     * The font size of the labels. The default value is 0 (labels not visible).
     */
    labelFontSize?: number;
    /**
     * The default tracker formatter
     */
    trackerStringFormatter?: TrackerStringFormatterType;
    /**
     * The default color-axis title
     */
    colorAxisTitle?: string;
    /**
     * The color axis.
     */
    colorAxis?: IColorAxis;
}
export declare const DefaultRectangleSeriesOptions: CreateRectangleSeriesOptions;
export declare const ExtendedDefaultRectangleSeriesOptions: CreateRectangleSeriesOptions;
/**
 * Represents a series that can be bound to a collection of RectangleItem.
 */
export declare class RectangleSeries extends XYAxisSeries {
    /**
     * The items originating from the items source.
     */
    private _actualItems;
    /**
     * The default tracker formatter
     */
    static readonly DefaultTrackerFormatString: TrackerStringFormatterType;
    /**
     * The default color-axis title
     */
    private static readonly DefaultColorAxisTitle;
    /**
     * Initializes a new instance of the HeatMapSeries class.
     */
    constructor(opt?: CreateRectangleSeriesOptions);
    getElementName(): string;
    private _minValue;
    /**
     * Gets the minimum value of the dataset.
     */
    get minValue(): number;
    private _maxValue;
    /**
     * Gets the maximum value of the dataset.
     */
    get maxValue(): number;
    private _colorAxis?;
    /**
     * Gets the color axis.
     */
    get colorAxis(): IColorAxis | undefined;
    protected set colorAxis(colorAxis: IColorAxis | undefined);
    /**
     * Gets or sets the color axis key.
     */
    colorAxisKey?: string;
    /**
     * Gets or sets the formatter for the cell labels. The default value is 0.00.
     */
    labelStringFormatter: LabelStringFormatterType;
    /**
     * Gets or sets the font size of the labels. The default value is 0 (labels not visible).
     */
    labelFontSize: number;
    /**
     * Gets or sets the delegate used to map from ItemsSeries.itemsSource to RectangleItem. The default is null.
     */
    mapping?: (item: any) => RectangleItem;
    /**
     * Gets the list of rectangles. This list is used if ItemsSeries.itemsSource is not set.
     */
    items: RectangleItem[];
    /**
     * Gets the list of rectangles that should be rendered.
     */
    protected get actualItems(): RectangleItem[];
    /**
     * Renders the series on the specified rendering context.
     * @param rc The rendering context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Updates the data.
     * @internal
     */
    updateData(): void;
    /**
     * Gets the item at the specified index.
     * @param i The index of the item.
     * @returns The item of the index.
     */
    protected getItem(i: number): any;
    /**
     * Clears or creates the actualItems list.
     */
    private clearActualItems;
    /**
     * Updates the points from the ItemsSeries.itemsSource.
     */
    private updateActualItems;
    /**
     * Renders the points as line, broken line and markers.
     * @param rc The rendering context.
     * @param items The Items to render.
     */
    protected renderRectangles(rc: IRenderContext, items: RectangleItem[]): Promise<void>;
    /**
     * Gets the point on the series that is nearest the specified point.
     * @param point The point.
     * @param interpolate Interpolate the series if this flag is set to true.
     * @returns A TrackerHitResult for the current hit.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Ensures that the axes of the series is defined.
     * @internal
     */
    ensureAxes(): void;
    /**
     * Updates the maximum and minimum values of the series for the x and y dimensions only.
     * @internal
     */
    updateMaxMinXY(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Updates the axes to include the max and min of this series.
     * @internal
     */
    updateAxisMaxMin(): void;
    /**
     * Tests if a DataPoint is inside the heat map
     * @param p The DataPoint to test.
     * @returns True if the point is inside the heat map.
     */
    private isPointInRange;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=RectangleSeries.d.ts.map